# Release Checklist

- [ ] Get master to the appropriate code release state.

- [ ] Publish release with new tag like `twitter-x.y.z`:
      https://github.com/python-twitter-tools/twitter/releases/new

- [ ] Check the tagged
      [GitHub Actions build](https://github.com/python-twitter-tools/twitter/actions?query=workflow%3ADeploy)
      has deployed to [PyPI](https://pypi.org/project/twitter/#history)
